hrap.tank.SatTank — hrap documentation

Skip to main content
`Ctrl`+`K`

# hrap.tank.SatTank

class hrap.tank.SatTank

  Methods

  classmethod new(V, get_sat_props, inj, vnt, T0, m0)

    Create a new tank filled with saturated fluid.

    Parameters:

      - V (float)

      - get_sat_props (Callable)

      - inj (Injector)

      - vnt (Vent)

      - T0 (float)

      - m0 (float)

  Attributes

  P
  Pdot
  Pdot_N
  Pdot_sum
  T
  Tdot
  m
  m_liq

    Mass of liquid

  m_vap
  mdot
  rho_liq
  rho_vap
  V
  get_sat_props
  inj
  vnt